# eric7.MicroPython.Devices.CircuitPythonUpdater.ShowBundlesDialog

Module implementing a dialog showing the available bundles and their modules.

### Global Attributes

None

### Classes

ShowBundlesDialog | Class implementing a dialog showing the available bundles and their modules.

### Functions

None

## ShowBundlesDialog

Class implementing a dialog showing the available bundles and their modules.

### Derived from

QDialog, Ui_ShowBundlesDialog

### Class Attributes

None

### Class Methods

None

### Methods

ShowBundlesDialog | Constructor

### Static Methods

None

#### ShowBundlesDialog (Constructor)

ShowBundlesDialog(withModules, parent=None)

Constructor

withModules (bool)
  flag indicating to list the modules and their version
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

Up